// Package extensions provides the Chrome DevTools Protocol
// commands, types, and events for the Extensions domain.
//
// Defines commands and events for browser extensions.
//
// Generated by the cdproto-gen command.
package extensions

// Code generated by cdproto-gen. DO NOT EDIT.

import (
	"context"

	"github.com/chromedp/cdproto/cdp"
	"github.com/mailru/easyjson"
)

// LoadUnpackedParams installs an unpacked extension from the filesystem
// similar to --load-extension CLI flags. Returns extension ID once the
// extension has been installed. Available if the client is connected using the
// --remote-debugging-pipe flag and the --enable-unsafe-extension-debugging flag
// is set.
type LoadUnpackedParams struct {
	Path string `json:"path"` // Absolute file path.
}

// LoadUnpacked installs an unpacked extension from the filesystem similar to
// --load-extension CLI flags. Returns extension ID once the extension has been
// installed. Available if the client is connected using the
// --remote-debugging-pipe flag and the --enable-unsafe-extension-debugging flag
// is set.
//
// See: https://chromedevtools.github.io/devtools-protocol/tot/Extensions#method-loadUnpacked
//
// parameters:
//
//	path - Absolute file path.
func LoadUnpacked(path string) *LoadUnpackedParams {
	return &LoadUnpackedParams{
		Path: path,
	}
}

// LoadUnpackedReturns return values.
type LoadUnpackedReturns struct {
	ID string `json:"id,omitempty"` // Extension id.
}

// Do executes Extensions.loadUnpacked against the provided context.
//
// returns:
//
//	id - Extension id.
func (p *LoadUnpackedParams) Do(ctx context.Context) (id string, err error) {
	// execute
	var res LoadUnpackedReturns
	err = cdp.Execute(ctx, CommandLoadUnpacked, p, &res)
	if err != nil {
		return "", err
	}

	return res.ID, nil
}

// GetStorageItemsParams gets data from extension storage in the given area.
// If keys is specified, these are used to filter the result.
type GetStorageItemsParams struct {
	ID          string      `json:"id"`             // ID of extension.
	StorageArea StorageArea `json:"storageArea"`    // StorageArea to retrieve data from.
	Keys        []string    `json:"keys,omitempty"` // Keys to retrieve.
}

// GetStorageItems gets data from extension storage in the given area. If
// keys is specified, these are used to filter the result.
//
// See: https://chromedevtools.github.io/devtools-protocol/tot/Extensions#method-getStorageItems
//
// parameters:
//
//	id - ID of extension.
//	storageArea - StorageArea to retrieve data from.
func GetStorageItems(id string, storageArea StorageArea) *GetStorageItemsParams {
	return &GetStorageItemsParams{
		ID:          id,
		StorageArea: storageArea,
	}
}

// WithKeys keys to retrieve.
func (p GetStorageItemsParams) WithKeys(keys []string) *GetStorageItemsParams {
	p.Keys = keys
	return &p
}

// GetStorageItemsReturns return values.
type GetStorageItemsReturns struct {
	Data easyjson.RawMessage `json:"data,omitempty"`
}

// Do executes Extensions.getStorageItems against the provided context.
//
// returns:
//
//	data
func (p *GetStorageItemsParams) Do(ctx context.Context) (data easyjson.RawMessage, err error) {
	// execute
	var res GetStorageItemsReturns
	err = cdp.Execute(ctx, CommandGetStorageItems, p, &res)
	if err != nil {
		return nil, err
	}

	return res.Data, nil
}

// Command names.
const (
	CommandLoadUnpacked    = "Extensions.loadUnpacked"
	CommandGetStorageItems = "Extensions.getStorageItems"
)
